# CIDAN

# Install Instructions
1. Make sure you have anaconda installed.
2. Then download the requirements.txt file.
3. In the same directory where it is located
run these commands:

```
conda create -n CIDAN python=3.7
conda activate CIDAN
pip install -r requirements.txt
python3 -m pip install --index-url https://test.pypi.org/simple/ --no-deps CIDAN
python -m CIDAN
```
 